@@ -55,7 +55,7 @@ class CVise:
 
     @classmethod
     def parse_pass_group_dict(cls, pass_group_dict, pass_options, external_programs, remove_pass,
-            clang_delta_std, not_c, no_renaming):
+            clang_delta_std, not_c, renaming):
         pass_group = {}
         removed_passes = set(remove_pass.split(",")) if remove_pass else set()
 
@@ -98,7 +98,7 @@ class CVise:
 
                 if not_c and "c" in pass_dict and pass_dict["c"]:
                     continue
-                elif no_renaming and "renaming" in pass_dict and pass_dict["renaming"]:
+                elif not renaming and "renaming" in pass_dict and pass_dict["renaming"]:
                     continue
 
                 pass_instance.clang_delta_std = clang_delta_std
