@@ -6,7 +6,7 @@ class CommentsPass(AbstractPass):
     def check_prerequisites(self):
         return True
 
-    def new(self, test_case):
+    def new(self, test_case, _=None):
         return -2
 
     def advance(self, test_case, state):
