@@ -30,7 +30,7 @@ class TernaryPass(AbstractPass):
 
         return m
 
-    def new(self, test_case):
+    def new(self, test_case, _=None):
         return self.__get_next_match(test_case, pos=0)
 
     def advance(self, test_case, state):
