@@ -457,7 +457,7 @@ class TestManager:
                         continue
 
             # create initial state
-            self.state = self.current_pass.new(self.current_test_case)
+            self.state = self.current_pass.new(self.current_test_case, self.check_sanity)
             self.skip = False
 
             while self.state != None and not self.skip:
